@@ -5,9 +5,9 @@
 ;; Author: Yuwei Tian <fishtai0@gmail.com>, Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.4
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4") (corfu "1.4"))
-;; Homepage: https://github.com/minad/corfu
+;; Version: 1.6
+;; Package-Requires: ((emacs "28.1") (compat "30") (corfu "1.6"))
+;; URL: https://github.com/minad/corfu
 
 ;; This file is part of GNU Emacs.
 
@@ -130,7 +130,7 @@ documentation from the backend is usually expensive."
     (left-margin-width . 1)
     (right-margin-width . 1)
     (word-wrap . t)
-    (fringe-indicator-alist (continuation)))
+    (char-property-alias-alist (face font-lock-face)))
   "Buffer parameters.")
 
 (defvar corfu-popupinfo--frame nil
@@ -158,6 +158,9 @@ all values are in pixels relative to the origin.  See
 (defvar corfu-popupinfo--lock-dir nil
   "Locked position direction of the info popup.")
 
+(defconst corfu-popupinfo--buffer " *corfu-popupinfo*"
+  "Buffer used by the popup.")
+
 (defconst corfu-popupinfo--initial-state
   (mapcar
    (lambda (k) (cons k (symbol-value k)))
@@ -243,7 +246,7 @@ all values are in pixels relative to the origin.  See
          (max-height (* lh corfu-popupinfo-max-height))
          (max-width (* cw corfu-popupinfo-max-width)))
     (or (when corfu-popupinfo-resize
-          (with-current-buffer " *corfu-popupinfo*"
+          (with-current-buffer corfu-popupinfo--buffer
             (cl-letf* (((window-dedicated-p) nil)
                        ((window-buffer) (current-buffer))
                        (size (window-text-pixel-size
@@ -345,12 +348,13 @@ form (X Y WIDTH HEIGHT DIR)."
   (when (and (corfu-popupinfo--visible-p corfu--frame))
     (let* ((cand-changed
             (not (and (corfu-popupinfo--visible-p)
-                      (equal candidate corfu-popupinfo--candidate))))
+                      (corfu--equal-including-properties
+                       candidate corfu-popupinfo--candidate))))
            (new-coords (frame-edges corfu--frame 'inner-edges))
            (coords-changed (not (equal new-coords corfu-popupinfo--coordinates))))
       (when cand-changed
         (if-let ((content (funcall corfu-popupinfo--function candidate)))
-            (with-current-buffer (corfu--make-buffer " *corfu-popupinfo*")
+            (with-current-buffer (corfu--make-buffer corfu-popupinfo--buffer)
               (with-silent-modifications
                 (erase-buffer)
                 (insert content)
@@ -371,21 +375,20 @@ form (X Y WIDTH HEIGHT DIR)."
                           (- (frame-pixel-width corfu-popupinfo--frame) border border)
                           (- (frame-pixel-height corfu-popupinfo--frame) border border)))))
                      (margin-quirk (not corfu-popupinfo--frame)))
-          (setq corfu-popupinfo--frame
-                (corfu--make-frame corfu-popupinfo--frame
-                                   area-x area-y area-w area-h
-                                   " *corfu-popupinfo*")
-                corfu-popupinfo--toggle t
-                corfu-popupinfo--lock-dir area-d
-                corfu-popupinfo--candidate candidate
-                corfu-popupinfo--coordinates new-coords)
-          ;; XXX HACK: Force margin update. For some reason, the call to
-          ;; `set-window-buffer' in `corfu--make-frame' is not effective the
-          ;; first time. Why does Emacs have all these quirks?
-          (when margin-quirk
-            (set-window-buffer
-             (frame-root-window corfu-popupinfo--frame)
-             " *corfu-popupinfo*")))))))
+          (with-current-buffer corfu-popupinfo--buffer
+            (setq corfu-popupinfo--frame
+                  (corfu--make-frame corfu-popupinfo--frame
+                                     area-x area-y area-w area-h)
+                  corfu-popupinfo--toggle t
+                  corfu-popupinfo--lock-dir area-d
+                  corfu-popupinfo--candidate candidate
+                  corfu-popupinfo--coordinates new-coords)
+            ;; XXX HACK: Force margin update. For some reason, the call to
+            ;; `set-window-buffer' in `corfu--make-frame' is not effective the
+            ;; first time. Why does Emacs have all these quirks?
+            (when margin-quirk
+              (set-window-buffer (frame-root-window corfu-popupinfo--frame)
+                                 corfu-popupinfo--buffer))))))))
 
 (defun corfu-popupinfo--hide ()
   "Clear the info popup buffer content and hide it."
@@ -400,7 +403,7 @@ visible, the other window is moved to beginning or end."
   (interactive "P")
   (if (corfu-popupinfo--visible-p)
       (with-selected-frame corfu-popupinfo--frame
-        (with-current-buffer " *corfu-popupinfo*"
+        (with-current-buffer corfu-popupinfo--buffer
           (with-no-warnings
             (end-of-buffer n))))
     (end-of-buffer-other-window n)))
@@ -421,7 +424,7 @@ the other window is scrolled."
   (interactive "p")
   (if (corfu-popupinfo--visible-p)
       (with-selected-frame corfu-popupinfo--frame
-        (with-current-buffer " *corfu-popupinfo*"
+        (with-current-buffer corfu-popupinfo--buffer
           (scroll-up n)))
     (scroll-other-window n)))
 
@@ -512,11 +515,11 @@ not be displayed until this command is called again, even if
   (cl-loop for (k . v) in corfu-popupinfo--initial-state do (set k v))
   (cl-callf2 assq-delete-all #'corfu-popupinfo-mode minor-mode-overriding-map-alist))
 
-;; Emacs 28: Do not show Corfu commands with M-X
-(dolist (sym '(corfu-popupinfo-scroll-down corfu-popupinfo-scroll-up
-               corfu-popupinfo-documentation corfu-popupinfo-location
-               corfu-popupinfo-beginning corfu-popupinfo-end
-               corfu-popupinfo-toggle))
+;; Do not show Corfu commands with M-X
+(dolist (sym '( corfu-popupinfo-scroll-down corfu-popupinfo-scroll-up
+                corfu-popupinfo-documentation corfu-popupinfo-location
+                corfu-popupinfo-beginning corfu-popupinfo-end
+                corfu-popupinfo-toggle))
   (put sym 'completion-predicate #'ignore))
 
 (provide 'corfu-popupinfo)
